@@ -5,7 +5,7 @@
 #ifndef __PAM_PG_OPTIONS_H_
 #define __PAM_PG_OPTIONS_H_
 
-#define PAM_PGSQL_FILECONF                 "/etc/pam_pgsql.conf"
+#define PAM_PGSQL_FILECONF                 SYSCONFDIR "/pam_pgsql.conf"
 #define PAM_PGSQL_PORT                     5432
 
 #include <sys/cdefs.h>
@@ -57,7 +57,6 @@ typedef struct modopt_s {
 } modopt_t;
 
 modopt_t * mod_options(int , const char **);
-void free_mod_options(modopt_t *options);
 
 
 int  pam_get_pass(pam_handle_t *, int, const char **, const char *, int);
